@@ -10,7 +10,7 @@ IceWM
 </name>
 
 <description>  
-lightweight environment 
+Lightweight window manager
 </description>
 
 <installable>
